==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/scom/kotlin/inputs/GmsaDetailsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.scom.kotlin.inputs

import com.pulumi.azurenative.scom.inputs.GmsaDetailsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Gmsa Details
 * @property dnsName Frontend DNS name for Load Balancer which will be used by Agents to initiate communication
 * @property gmsaAccount gMSA account under which context all Management Server services will run
 * @property loadBalancerIP Frontend IP configuration for Load Balancer, which should be an available IP in customer VNet
 * @property managementServerGroupName OnPrem AD Computer Group where we will join VMs for ease of management
 */
public data class GmsaDetailsArgs(
    public val dnsName: Output<String>? = null,
    public val gmsaAccount: Output<String>? = null,
    public val loadBalancerIP: Output<String>? = null,
    public val managementServerGroupName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.scom.inputs.GmsaDetailsArgs> {
    override fun toJava(): com.pulumi.azurenative.scom.inputs.GmsaDetailsArgs =
        com.pulumi.azurenative.scom.inputs.GmsaDetailsArgs.builder()
            .dnsName(dnsName?.applyValue({ args0 -> args0 }))
            .gmsaAccount(gmsaAccount?.applyValue({ args0 -> args0 }))
            .loadBalancerIP(loadBalancerIP?.applyValue({ args0 -> args0 }))
            .managementServerGroupName(managementServerGroupName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [GmsaDetailsArgs].
 */
@PulumiTagMarker
public class GmsaDetailsArgsBuilder internal constructor() {
    private var dnsName: Output<String>? = null

    private var gmsaAccount: Output<String>? = null

    private var loadBalancerIP: Output<String>? = null

    private var managementServerGroupName: Output<String>? = null

    /**
     * @param value Frontend DNS name for Load Balancer which will be used by Agents to initiate communication
     */
    @JvmName("xgoxkwfwecwhuvft")
    public suspend fun dnsName(`value`: Output<String>) {
        this.dnsName = value
    }

    /**
     * @param value gMSA account under which context all Management Server services will run
     */
    @JvmName("olnlvmfhkagseuxh")
    public suspend fun gmsaAccount(`value`: Output<String>) {
        this.gmsaAccount = value
    }

    /**
     * @param value Frontend IP configuration for Load Balancer, which should be an available IP in customer VNet
     */
    @JvmName("vnixjksokggwyxbf")
    public suspend fun loadBalancerIP(`value`: Output<String>) {
        this.loadBalancerIP = value
    }

    /**
     * @param value OnPrem AD Computer Group where we will join VMs for ease of management
     */
    @JvmName("rqkldhngsdnxpxom")
    public suspend fun managementServerGroupName(`value`: Output<String>) {
        this.managementServerGroupName = value
    }

    /**
     * @param value Frontend DNS name for Load Balancer which will be used by Agents to initiate communication
     */
    @JvmName("vyeaxdhmgegxagio")
    public suspend fun dnsName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dnsName = mapped
    }

    /**
     * @param value gMSA account under which context all Management Server services will run
     */
    @JvmName("dwyajwekqodngdxi")
    public suspend fun gmsaAccount(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.gmsaAccount = mapped
    }

    /**
     * @param value Frontend IP configuration for Load Balancer, which should be an available IP in customer VNet
     */
    @JvmName("dbgqybqxcnsjaclq")
    public suspend fun loadBalancerIP(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.loadBalancerIP = mapped
    }

    /**
     * @param value OnPrem AD Computer Group where we will join VMs for ease of management
     */
    @JvmName("otiiiancywyrmted")
    public suspend fun managementServerGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.managementServerGroupName = mapped
    }

    internal fun build(): GmsaDetailsArgs = GmsaDetailsArgs(
        dnsName = dnsName,
        gmsaAccount = gmsaAccount,
        loadBalancerIP = loadBalancerIP,
        managementServerGroupName = managementServerGroupName,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/scom/kotlin/inputs/GmsaDetailsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.scom.kotlin.inputs

import com.pulumi.azurenative.scom.inputs.GmsaDetailsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Gmsa Details
 * @property dnsName Frontend DNS name for Load Balancer which will be used by Agents to initiate communication
 * @property gmsaAccount gMSA account under which context all Management Server services will run
 * @property loadBalancerIP Frontend IP configuration for Load Balancer, which should be an available IP in customer VNet
 * @property managementServerGroupName OnPrem AD Computer Group where we will join VMs for ease of management
 */
public data class GmsaDetailsArgs(
    public val dnsName: Output<String>? = null,
    public val gmsaAccount: Output<String>? = null,
    public val loadBalancerIP: Output<String>? = null,
    public val managementServerGroupName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.scom.inputs.GmsaDetailsArgs> {
    override fun toJava(): com.pulumi.azurenative.scom.inputs.GmsaDetailsArgs =
        com.pulumi.azurenative.scom.inputs.GmsaDetailsArgs.builder()
            .dnsName(dnsName?.applyValue({ args0 -> args0 }))
            .gmsaAccount(gmsaAccount?.applyValue({ args0 -> args0 }))
            .loadBalancerIP(loadBalancerIP?.applyValue({ args0 -> args0 }))
            .managementServerGroupName(managementServerGroupName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [GmsaDetailsArgs].
 */
@PulumiTagMarker
public class GmsaDetailsArgsBuilder internal constructor() {
    private var dnsName: Output<String>? = null

    private var gmsaAccount: Output<String>? = null

    private var loadBalancerIP: Output<String>? = null

    private var managementServerGroupName: Output<String>? = null

    /**
     * @param value Frontend DNS name for Load Balancer which will be used by Agents to initiate communication
     */
    @JvmName("jqfnquomfsjtswya")
    public suspend fun dnsName(`value`: Output<String>) {
        this.dnsName = value
    }

    /**
     * @param value gMSA account under which context all Management Server services will run
     */
    @JvmName("osrldjejdskvuivs")
    public suspend fun gmsaAccount(`value`: Output<String>) {
        this.gmsaAccount = value
    }

    /**
     * @param value Frontend IP configuration for Load Balancer, which should be an available IP in customer VNet
     */
    @JvmName("reqmnwytsqsxuhek")
    public suspend fun loadBalancerIP(`value`: Output<String>) {
        this.loadBalancerIP = value
    }

    /**
     * @param value OnPrem AD Computer Group where we will join VMs for ease of management
     */
    @JvmName("ontaudrymojqniro")
    public suspend fun managementServerGroupName(`value`: Output<String>) {
        this.managementServerGroupName = value
    }

    /**
     * @param value Frontend DNS name for Load Balancer which will be used by Agents to initiate communication
     */
    @JvmName("ngsfpuhrubcoruud")
    public suspend fun dnsName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dnsName = mapped
    }

    /**
     * @param value gMSA account under which context all Management Server services will run
     */
    @JvmName("oabbjnqksiodbcbc")
    public suspend fun gmsaAccount(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.gmsaAccount = mapped
    }

    /**
     * @param value Frontend IP configuration for Load Balancer, which should be an available IP in customer VNet
     */
    @JvmName("avtmxloywnipgqkr")
    public suspend fun loadBalancerIP(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.loadBalancerIP = mapped
    }

    /**
     * @param value OnPrem AD Computer Group where we will join VMs for ease of management
     */
    @JvmName("hpkfyypoatoiarhm")
    public suspend fun managementServerGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.managementServerGroupName = mapped
    }

    internal fun build(): GmsaDetailsArgs = GmsaDetailsArgs(
        dnsName = dnsName,
        gmsaAccount = gmsaAccount,
        loadBalancerIP = loadBalancerIP,
        managementServerGroupName = managementServerGroupName,
    )
}
